summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMark Washenberger <mark.washenberger@rackspace.com>2011-05-12 02:27:47 -0400
committerMark Washenberger <mark.washenberger@rackspace.com>2011-05-12 02:27:47 -0400
commit81b1cfc2db7f898263c0c40665769424ca5530ef (patch)
tree2f9606c2d3885a5eb459646b81777a23a2eb0be0
parent79466a3a7b67478871f178115d95378643caf29f (diff)
rename quota column to 'hard_limit' to make it simpler to avoid collisions with sql keyword 'limit'
-rw-r--r--nova/db/sqlalchemy/api.py6
-rw-r--r--nova/db/sqlalchemy/migrate_repo/versions/016_make_quotas_key_and_value.py14
-rw-r--r--nova/db/sqlalchemy/models.py4
3 files changed, 12 insertions, 12 deletions
diff --git a/nova/db/sqlalchemy/api.py b/nova/db/sqlalchemy/api.py
index 56b40f95b..ea0bbb06e 100644
--- a/nova/db/sqlalchemy/api.py
+++ b/nova/db/sqlalchemy/api.py
@@ -1518,7 +1518,7 @@ def quota_get_all_by_project(context, project_id):
filter_by(deleted=False).\
all()
for row in rows:
- result[row.resource] = row.limit
+ result[row.resource] = row.hard_limit
return result
@@ -1527,7 +1527,7 @@ def quota_create(context, project_id, resource, limit):
quota_ref = models.Quota()
quota_ref.project_id = project_id
quota_ref.resource = resource
- quota_ref.limit = limit
+ quota_ref.hard_limit = limit
quota_ref.save()
return quota_ref
@@ -1537,7 +1537,7 @@ def quota_update(context, project_id, resource, limit):
session = get_session()
with session.begin():
quota_ref = quota_get(context, project_id, resource, session=session)
- quota_ref.limit = limit
+ quota_ref.hard_limit = limit
quota_ref.save(session=session)
diff --git a/nova/db/sqlalchemy/migrate_repo/versions/016_make_quotas_key_and_value.py b/nova/db/sqlalchemy/migrate_repo/versions/016_make_quotas_key_and_value.py
index 03d346af4..a2d8192ca 100644
--- a/nova/db/sqlalchemy/migrate_repo/versions/016_make_quotas_key_and_value.py
+++ b/nova/db/sqlalchemy/migrate_repo/versions/016_make_quotas_key_and_value.py
@@ -71,7 +71,7 @@ def new_style_quotas_table(name):
assert_unicode=None, unicode_error=None,
_warn_on_bytestring=False),
nullable=False),
- Column('limit', Integer(), nullable=True),
+ Column('hard_limit', Integer(), nullable=True),
)
@@ -111,8 +111,8 @@ def convert_forward(migrate_engine, old_quotas, new_quotas):
quotas = list(migrate_engine.execute(old_quotas.select()))
for quota in quotas:
for resource in resources:
- limit = getattr(quota, resource)
- if limit is None:
+ hard_limit = getattr(quota, resource)
+ if hard_limit is None:
continue
insert = new_quotas.insert().values(
created_at=quota.created_at,
@@ -121,7 +121,7 @@ def convert_forward(migrate_engine, old_quotas, new_quotas):
deleted=quota.deleted,
project_id=quota.project_id,
resource=resource,
- limit=limit)
+ hard_limit=hard_limit)
migrate_engine.execute(insert)
@@ -153,21 +153,21 @@ def convert_backward(migrate_engine, old_quotas, new_quotas):
quotas = {}
for quota in migrate_engine.execute(new_quotas.select()):
if (quota.resource not in resources
- or quota.limit is None or quota.deleted):
+ or quota.hard_limit is None or quota.deleted):
continue
if not quota.project_id in quotas:
quotas[quota.project_id] = {
'project_id': quota.project_id,
'created_at': quota.created_at,
'updated_at': quota.updated_at,
- quota.resource: quota.limit
+ quota.resource: quota.hard_limit
}
else:
quotas[quota.project_id]['created_at'] = earliest(
quota.created_at, quotas[quota.project_id]['created_at'])
quotas[quota.project_id]['updated_at'] = latest(
quota.updated_at, quotas[quota.project_id]['updated_at'])
- quotas[quota.project_id][quota.resource] = quota.limit
+ quotas[quota.project_id][quota.resource] = quota.hard_limit
for quota in quotas.itervalues():
insert = old_quotas.insert().values(**quota)
diff --git a/nova/db/sqlalchemy/models.py b/nova/db/sqlalchemy/models.py
index e477040d3..0b46d5a05 100644
--- a/nova/db/sqlalchemy/models.py
+++ b/nova/db/sqlalchemy/models.py
@@ -317,7 +317,7 @@ class Quota(BASE, NovaBase):
If there is no row for a given project id and resource, then
the default for the deployment is used. If the row is present
but the limit is Null, then the resource is unlimited.
"""
__tablename__ = 'quotas'
@@ -326,7 +326,7 @@ class Quota(BASE, NovaBase):
project_id = Column(String(255), index=True)
resource = Column(String(255))
- limit = Column(Integer, nullable=True)
+ hard_limit = Column(Integer, nullable=True)
class ExportDevice(BASE, NovaBase):
@@ -317,7 +317,7 @@ class Quota(BASE, NovaBase):
If there is no row for a given project id and resource, then
the default for the deployment is used. If the row is present
- but the limit is Null, then the resource is unlimited.
+ but the hard limit is Null, then the resource is unlimited.
"""
__tablename__ = 'quotas'